#
# spec file for package xorg-cf-files
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xorg-cf-files
Version:        1.0.8
Release:        1.2
Summary:        Data files for the imake utility
License:        MIT
Group:          Development/Tools/Building
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/util/%{name}-%{version}.tar.xz
Patch1:         u_xorg-cf-files-D_DEFAULT_SOURCE.patch
BuildRequires:  font-util >= 1.1
BuildRequires:  pkgconfig(xorg-macros) >= 1.4
Requires:       gccmakedep
Requires:       imake
Requires:       makedepend
# This was part of the xorg-x11-util-devel package up to version 7.6
Conflicts:      xorg-x11-util-devel <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The xorg-cf-files package contains the data files for the imake utility,
defining the known settings for a wide variety of platforms (many of
which have not been verified or tested in over a decade), and for many
of the libraries formerly delivered in the X.Org monolithic releases.

The X Window System used imake extensively up through the X11R6.9
release, for both full builds within the source tree and external
software. X has since moved to GNU autoconf and automake for its build
system in X11R7.0 and later releases, but still maintains imake for
building existing external software programs that have not yet
converted.

%define _configdir %{_datadir}/X11/config

%prep
%setup -q
%patch1 -p1

cat > host.def << EOF
#define ConfigDir %_configdir
#define XAppLoadDir /usr/share/X11/app-defaults
#define UseSeparateConfDir NO
#define ManPath /usr/share/man
%ifarch ppc64 s390x x86_64 sparc64 riscv64
#define ModuleDir /usr/lib64/xorg/modules
%else
#define ModuleDir /usr/lib/xorg/modules
%endif
#ifdef  i386Architecture
#undef  DefaultGcc2i386Opt
#define DefaultGcc2i386Opt      -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  MipsArchitecture
#undef  DefaultGcc2MipsOpt
#define DefaultGcc2MipsOpt      -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  PpcArchitecture
#undef  DefaultGcc2PpcOpt
#define DefaultGcc2PpcOpt       -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  Ppc64Architecture
#undef  DefaultGcc2Ppc64Opt
#define DefaultGcc2Ppc64Opt     -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  AMD64Architecture
#undef  DefaultGcc2AMD64Opt
#define DefaultGcc2AMD64Opt     -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  AArch64Architecture
#undef  DefaultGcc2AArch64Opt
#define DefaultGcc2AArch64Opt   -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  s390xArchitecture
#undef  OptimizedCDebugFlags
#define OptimizedCDebugFlags    -O2 -Wall -fno-strict-aliasing
#endif
#ifdef  ia64Architecture
#undef  OptimizedCDebugFlags
#define OptimizedCDebugFlags    -O2 -Wall -fno-strict-aliasing
#endif
#if defined(SparcArchitecture) || defined(Sparc64Architecture)
#undef  OptimizedCDebugFlags
#define OptimizedCDebugFlags    -O2 -Wall -fno-strict-aliasing
# undef HaveLib64
#if defined(Sparc64Architecture)
# define HaveLib64    YES
#else
# define HaveLib64    NO
#endif
#endif
#ifdef  RiscV64Architecture
#undef  DefaultGcc2RiscV64Opt
#define DefaultGcc2RiscV64Opt   -O2 -Wall -fno-strict-aliasing
#endif
EOF

%build
%configure --with-config-dir=%_configdir
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%license COPYING
%doc ChangeLog README
%dir %{_datadir}/X11
%{_datadir}/X11/config/

%changelog
* Wed Feb 22 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.8
  * This is a minor update to ship the contributed support for Linux
    on RISC-V & LoongArch, and AArch64 on Darwin (MacOS), as well as
    to fix incompatibility when using GNU binutils 2.36 and later on
    FreeBSD, and to correct the setting of the rarely (never?) used
    ENCODINGSDIR in site.def.
- supersedes u_riscv.patch
- refreshed u_xorg-cf-files-D_DEFAULT_SOURCE.patch
* Mon Aug  2 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.7
  * This is a minor update to resolve a compatibility issue with
    GNU binutils 2.36.
- supersedes u_ar-clq-Imake.tmpl-binutils_2.36.patch
- refreshed u_riscv.patch, u_xorg-cf-files-D_DEFAULT_SOURCE.patch
* Wed Mar  3 2021 Marguerite Su <i@marguerite.su>
- u_ar-clq-Imake.tmpl-binutils_2.36.patch
  * debian#981072: the previously ignored "l" option
    (did no actual work) was implemented to specfily
    dependencies of library. any wrong usage will now
    trigger "ar: libdeps specified more than once"
    error.
* Mon Jan  4 2021 Stefan Dirsch <sndirsch@suse.com>
- u_xorg-cf-files-D_DEFAULT_SOURCE.patch
  - switched from usage of "-D_BSD_SOURCE -D_SVID_SOURCE" to
    "D_DEFAULT_SOURCE" as suggested by gcc (boo#1180429)
* Thu Sep 27 2018 sndirsch@suse.com
- no longer use $RPM_OPT_FLAGS in order to make it a real noarch
  package (boo#1110020)
* Tue Feb 27 2018 schwab@suse.de
- u_riscv.patch: Add support for riscv64
* Tue Dec 22 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.6:
  + configure: Drop AM_MAINTAINER_MODE
  + autogen.sh: Honor NOCONFIGURE=1
  + Remove very out of date OS2 DLL mappings for no-longer-shipped makedef.cmd
  + sun.cf: limit SysV man page sections to Solaris 2.0-11
  + sun.cf: Sun Studio 12.0 & later compilers prefer -m32/-m64
  + README: reword status section
  + Remove os2def.db from EXTRA_DIST
* Wed Aug 14 2013 zaitor@opensuse.org
- Update to version 1.0.5:
  + sun.cf: stop linking libraries merged into libc in later
    Solaris releases.
  + Remove xprint_host.def.
  + Trim trailing whitespace.
  + Add Aarch64 support.
  + Update xorgversion.def from 7.6 to 7.7.
  + On Solaris 11 & later, use /usr/gnu/bin/install for InstallCmd.
- Drop aarch64-support.diff, fixed upstream.
* Sun Mar  3 2013 schwab@suse.de
- Add aarch64 to the list of lib64 platforms
* Fri Mar  1 2013 dmueller@suse.com
- add aarch64-support.diff:
  Add support for aarch64
* Tue Jun 26 2012 sndirsch@suse.com
- finally changed BuildRequires to font-util (see change before)
* Thu Apr 19 2012 vuntz@opensuse.org
- Change font-util BuildRequires to xorg-x11-fonts-devel:
  xorg-x11-fonts-devel hasn't been renamed yet.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xorg-cf-files from xorg-x11-util-devel.
  Initial version: 1.0.4.
